@@ -5,6 +5,7 @@ declare(strict_types=1);
 namespace LaminasTest\Stdlib;
 
 use Laminas\Stdlib\PriorityQueue;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\TestCase;
 use stdClass;
 
@@ -15,16 +16,15 @@ use function serialize;
 use function unserialize;
 use function var_export;
 
-/**
- * @group      Laminas_Stdlib
- */
+#[Group('Laminas_Stdlib')]
 class PriorityQueueTest extends TestCase
 {
-    /** @var PriorityQueue */
-    protected $queue;
+    /** @var PriorityQueue<string, int> */
+    private PriorityQueue $queue;
 
     protected function setUp(): void
     {
+        /** @psalm-var PriorityQueue<string, int> $this->queue */
         $this->queue = new PriorityQueue();
         $this->queue->insert('foo', 3);
         $this->queue->insert('bar', 4);
@@ -36,7 +36,8 @@ class PriorityQueueTest extends TestCase
     {
         $s            = serialize($this->queue);
         $unserialized = unserialize($s);
-        $count        = count($this->queue);
+        self::assertInstanceOf(PriorityQueue::class, $unserialized);
+        $count = count($this->queue);
         self::assertSame(
             $count,
             count($unserialized),
